flake: { config, lib, pkgs, ...} :
let
  cfg = config.services.push-notification-server;
  name = "push-notification-server";
  system = pkgs.system;
  packages = flake.outputs.packages.${system};
in {
  options = {
    services.push-notification-server = {
      enable = lib.mkEnableOption "Enable the push notification server";
      user = lib.mkOption {
        type = lib.types.str;
        description = "User to run the push notification server as";
      };
      port = lib.mkOption {
        type = lib.types.int;
        default = 8080;
        description = "Port for the push notification server";
      };
    };
  };
  config = lib.mkIf cfg.enable {

    systemd.services.push-notification-server = {
      wantedBy = [ "multi-user.target" ];
      wants = [ "network-online.target" ];
      after = [ "network-online.target" ];
      description = "push notification server";
      environment = {
        PORT = "${toString cfg.port}";
      }; 
      serviceConfig = {
        Type = "simple";
        User = name;
        DynamicUser = true;
        RuntimeDirectory = "push-notification-server";
        StateDirectory = "push-notification-server";
        AmbientCapabilities = if cfg.port < 1024 then [ "CAP_NET_BIND_SERVICE" ] else [];
        ExecStart = "${packages.push-notifications-test}/bin/push-notifications-test --port ${toString cfg.port}";
        Restart = "always";
      };
    };

  };
}
